==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Startseite',
	'article' => 'Artikel',
	'articles' => 'Artikel',
	'articles_auteur' => 'Artikel dieses Autors',
	'articles_populaires' => 'Die beliebtesten Artikel',
	'articles_rubrique' => 'Artikel dieser Rubrik',
	'aucun_article' => 'Unter dieser Adresse gibt es keinen Artikel.',
	'aucun_auteur' => 'Unter dieser Adresse gibt es keinen Autor.',
	'aucun_site' => 'Unter dieser Adresse gibt es keien Website.',
	'aucune_breve' => 'Unter dieser Adresse gibt es keine Meldung.',
	'aucune_rubrique' => 'Unter dieser Adresse gibt es keine Rubrik.',
	'auteur' => 'Autor',
	'autres' => 'Andere',
	'autres_breves' => 'Weitere Meldungen.',
	'autres_groupes_mots_clefs' => 'Weitere Schlagwortgruppen',
	'autres_sites' => 'Weitere Websites',

	// B
	'bonjour' => 'Hallo',

	// C
	'commenter_site' => 'Website kommentieren',
	'contact' => 'Kontakt',
	'copie_document_impossible' => 'Dokument kann nicht kopiert werden',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Neuester Eintrag',
	'dernieres_breves' => 'Neue Meldungen',
	'derniers_articles' => 'Neueste Artikel',
	'derniers_commentaires' => 'Neueste Kommentare',
	'derniers_messages_forum' => 'Neuste Forumsbeiträge',

	// E
	'edition_mode_texte' => 'Im Textmodus bearbeiten ',
	'en_reponse' => 'Antwort auf:',
	'en_resume' => 'Als Zusammenfassung',
	'envoyer_message' => 'Nachricht senden',
	'espace_prive' => 'Redaktion',

	// F
	'formats_acceptes' => 'Akzeptierte Formate: @formats@.',

	// H
	'hierarchie_site' => 'Baumstruktur der Website',

	// J
	'jours' => 'Tage',

	// L
	'lien_connecter' => 'Login',

	// M
	'meme_auteur' => 'Vom gleichen Autor',
	'meme_rubrique' => 'In der gleichen Rubrik',
	'memes_auteurs' => 'Von den gleichen Autoren',
	'message' => 'Nachricht',
	'messages_forum' => 'Nachrichten',
	'messages_recents' => 'Neuste Forumsbeiträge',
	'mots_clef' => 'Schlagwort',
	'mots_clefs' => 'Schlagworte',
	'mots_clefs_meme_groupe' => 'Schlagworte der gleichen Kategorie',

	// N
	'navigation' => 'Navigation',
	'nom' => 'Name',
	'nouveautes' => 'Neuigkeiten',
	'nouveautes_web' => 'Neues im WWW',
	'nouveaux_articles' => 'Neue Artikel',
	'nouvelles_breves' => 'Neue Meldungen',

	// P
	'page_precedente' => 'vorige Seite',
	'page_suivante' => 'nächste Seite',
	'par_auteur' => 'von ',
	'participer_site' => 'Sie können bei dieser Website mitmachen, wenn Sie sich anmelden. Sie erhalten sofort eine E-Mail mit den Zugangsdaten zum Redaktionssystem.',
	'plan_site' => 'Sitemap',
	'popularite' => 'Beliebtheit',
	'poster_message' => 'Nachricht senden',
	'proposer_site' => 'Sie können in dieser Rubrik eine Seite vorschlagen :',

	// R
	'repondre_article' => 'auf diesen Artikel antworten',
	'repondre_breve' => 'auf diese Meldung antworten',
	'resultats_recherche' => 'Suchergebnis(se)',
	'retour_debut_forums' => 'Zurück zum Beginn des Forums',
	'rubrique' => 'Rubrik',
	'rubriques' => 'Rubriken',

	// S
	'signatures_petition' => 'Unterschrift',
	'site_realise_avec_spip' => 'Realisiert mit SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Unterrubriken',
	'spam' => 'SPAM',
	'suite' => 'weiter',
	'sur_web' => 'Im WWW',
	'syndiquer_rubrique' => 'Diese Rubrik per RSS einbinden',
	'syndiquer_site' => 'Die ganze Website mit RSS einbinden',

	// T
	'texte_lettre_information' => 'Dies ist der Newsletter der Website ',
	'texte_lettre_information_2' => 'Diese Mail informiert über die Neuerscheinungen der letzten',

	// V
	'ver_imprimer' => 'Druckversion',
	'voir_en_ligne' => 'Online ansehen',
	'voir_squelette' => 'Layoutvorlage dieser Seite ansehen'
);

==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Startseite',
	'article' => 'Artikel',
	'articles' => 'Artikel',
	'articles_auteur' => 'Artikel dieses Autors',
	'articles_populaires' => 'Die beliebtesten Artikel',
	'articles_rubrique' => 'Artikel dieser Rubrik',
	'aucun_article' => 'Unter dieser Adresse gibt es keinen Artikel.',
	'aucun_auteur' => 'Unter dieser Adresse gibt es keinen Autor.',
	'aucun_site' => 'Unter dieser Adresse gibt es keien Website.',
	'aucune_breve' => 'Unter dieser Adresse gibt es keine Meldung.',
	'aucune_rubrique' => 'Unter dieser Adresse gibt es keine Rubrik.',
	'auteur' => 'Autor',
	'autres' => 'Andere',
	'autres_breves' => 'Weitere Meldungen.',
	'autres_groupes_mots_clefs' => 'Weitere Schlagwortgruppen',
	'autres_sites' => 'Weitere Websites',

	// B
	'bonjour' => 'Hallo',

	// C
	'commenter_site' => 'Website kommentieren',
	'contact' => 'Kontakt',
	'copie_document_impossible' => 'Dokument kann nicht kopiert werden',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Neuester Eintrag',
	'dernieres_breves' => 'Neue Meldungen',
	'derniers_articles' => 'Neueste Artikel',
	'derniers_commentaires' => 'Neueste Kommentare',
	'derniers_messages_forum' => 'Neue Forumsbeiträge',

	// E
	'edition_mode_texte' => 'Im Textmodus bearbeiten ',
	'en_reponse' => 'Antwort auf:',
	'en_resume' => 'Als Zusammenfassung',
	'envoyer_message' => 'Nachricht senden',
	'espace_prive' => 'Redaktion',

	// F
	'formats_acceptes' => 'Akzeptierte Formate: @formats@.',

	// H
	'hierarchie_site' => 'Baumstruktur der Website',

	// J
	'jours' => 'Tage',

	// L
	'lien_connecter' => 'Login',

	// M
	'meme_auteur' => 'Vom gleichen Autor',
	'meme_rubrique' => 'In der gleichen Rubrik',
	'memes_auteurs' => 'Von den gleichen Autoren',
	'message' => 'Nachricht',
	'messages_forum' => 'Nachrichten',
	'messages_recents' => 'Neue Forumsbeiträge',
	'mots_clef' => 'Schlagwort',
	'mots_clefs' => 'Schlagworte',
	'mots_clefs_meme_groupe' => 'Schlagworte der gleichen Kategorie',

	// N
	'navigation' => 'Navigation',
	'nom' => 'Name',
	'nouveautes' => 'Neuigkeiten',
	'nouveautes_web' => 'Neues im WWW',
	'nouveaux_articles' => 'Neue Artikel',
	'nouvelles_breves' => 'Neue Meldungen',

	// P
	'page_precedente' => 'vorige Seite',
	'page_suivante' => 'nächste Seite',
	'par_auteur' => 'von ',
	'participer_site' => 'Sie können bei dieser Website mitmachen, wenn Sie sich anmelden. Sie erhalten sofort eine E-Mail mit den Zugangsdaten zum Redaktionssystem.',
	'plan_site' => 'Sitemap',
	'popularite' => 'Beliebtheit',
	'poster_message' => 'Nachricht senden',
	'proposer_site' => 'Sie können in dieser Rubrik eine Seite vorschlagen :',

	// R
	'repondre_article' => 'auf diesen Artikel antworten',
	'repondre_breve' => 'auf diese Meldung antworten',
	'resultats_recherche' => 'Suchergebnis(se)',
	'retour_debut_forums' => 'Zurück zum Beginn des Forums',
	'rubrique' => 'Rubrik',
	'rubriques' => 'Rubriken',

	// S
	'signatures_petition' => 'Unterschrift',
	'site_realise_avec_spip' => 'Realisiert mit SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Unterrubriken',
	'spam' => 'SPAM',
	'suite' => 'weiter',
	'sur_web' => 'Im WWW',
	'syndiquer_rubrique' => 'Diese Rubrik per RSS einbinden',
	'syndiquer_site' => 'Die ganze Website mit RSS einbinden',

	// T
	'texte_lettre_information' => 'Dies ist der Newsletter der Website ',
	'texte_lettre_information_2' => 'Diese Mail informiert über die Neuerscheinungen der letzten',

	// V
	'ver_imprimer' => 'Druckversion',
	'voir_en_ligne' => 'Online ansehen',
	'voir_squelette' => 'Layoutvorlage dieser Seite ansehen'
);
